@@ -10,22 +10,25 @@ class NeuralEntity(Entity):
 
     @property
     def probe_info(self):
+        """Additional information about the signal source"""
         return self._info['ProbeInfo']
 
     @property
     def source_entity_id(self):
-        """[**Optional**] Id of the source entity of this spike, if any.
+        """[*Optional*] Id of the source entity of this spike, if any.
         For example the spike waveform of the action potential corresponding
         to this spike might have been recoreded in a segment entity."""
 	return self._info['SourceEntityID']
 
     @property
     def source_unit_id(self):
+        """[*Optional*] unit id used in the source entity
+        (cf. :func:`source_entity_id`)"""
         return self._info['SourceUnitID']
 
     def get_data (self, index=0, count=-1):
         """Retrieve the spike times associated with this entity. A subset
-        of the data can be requested via the ``inde`` and ``count``
+        of the data can be requested via the ``index`` and ``count``
         parameters."""
         lib = self.file.library
         if count < 0:
